**Deployed:** DayOfWeek, Month D, YYYY
**Current Contributors:** [insert GitHub @username comma list]

[Release description (1-2 paras)]

**Major Changes:**

- [Change 1]
- [Change 2]

Minor Changes:

- [Change 1]
- [Change 2]